Documentation
¶
Index ¶
- func Black() *colorPrinter
- func Blue() *colorPrinter
- func Cyan() *colorPrinter
- func GetConfigFileDir() (string, error)
- func Green() *colorPrinter
- func IsJsonArray(value string) bool
- func IsRepeatedField(f string) bool
- func Magenta() *colorPrinter
- func OpenBrowser(url string) error
- func ParseToJsonArrayOrObject(s string) (interface{}, bool)
- func Print(a ...interface{}) *colorPrinter
- func Printf(format string, a ...interface{}) *colorPrinter
- func Println(a ...interface{}) *colorPrinter
- func Red() *colorPrinter
- func ShowJson(data interface{}, color bool)
- func UnixTimestampToTime(ts int64) time.Time
- func White() *colorPrinter
- func Yellow() *colorPrinter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetConfigFileDir ¶
func IsJsonArray ¶
func IsRepeatedField ¶
func ParseToJsonArrayOrObject ¶
ParseToJsonArrayOrObject try to parse string to json array or json object
func ShowJson ¶ added in v1.0.1
func ShowJson(data interface{}, color bool)
ShowJson print data as json data should be map[string]interface{}
func UnixTimestampToTime ¶ added in v1.0.39
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.